==> haskell-ghc-typelits-knownnat-0.7.4-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-knownnat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-knownnat
version:              0.7.4
visibility:           public
id:                   ghc-typelits-knownnat-0.7.4-BMTYI6iGJ2D7hVGOZuo44O
key:                  ghc-typelits-knownnat-0.7.4-BMTYI6iGJ2D7hVGOZuo44O
license:              BSD-2-Clause
copyright:
    Copyright © 2016     , University of Twente,
    2017-2018, QBayLogic B.V.,
    2017     , Google Inc.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://clash-lang.org/
synopsis:             Derive KnownNat constraints from other KnownNat constraints
description:
    A type checker plugin for GHC that can derive \"complex\" @KnownNat@
    constraints from other simple/variable @KnownNat@ constraints. i.e. without
    this plugin, you must have both a @KnownNat n@ and a @KnownNat (n+2)@
    constraint in the type signature of the following function:

    @
    f :: forall n . (KnownNat n, KnownNat (n+2)) => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @

    Using the plugin you can omit the @KnownNat (n+2)@ constraint:

    @
    f :: forall n . KnownNat n => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @

    The plugin can derive @KnownNat@ constraints for types consisting of:

    * Type variables, when there is a corresponding @KnownNat@ constraint

    * Type-level naturals

    * Applications of the arithmetic expression: +,-,*,^

    * Type functions, when there is either:

    1. a matching given @KnownNat@ constraint; or

    2. a corresponding @KnownNat\<N\>@ instance for the type function

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.KnownNat.Solver
    @

    Pragma to the header of your file.

category:             Type System
abi:                  a735446b7bd9d09750ce8a7b2bdaa861
exposed:              True
exposed-modules:      GHC.TypeLits.KnownNat GHC.TypeLits.KnownNat.Solver
hidden-modules:       GHC.TypeLits.KnownNat.TH
import-dirs:          /usr/lib/ghc-8.10.3/site-local/ghc-typelits-knownnat-0.7.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ghc-typelits-knownnat-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/ghc-typelits-knownnat-0.7.4

hs-libraries:         HSghc-typelits-knownnat-0.7.4-BMTYI6iGJ2D7hVGOZuo44O
depends:
    base-4.14.1.0 ghc-8.10.3 ghc-prim-0.6.1
    ghc-tcplugins-extra-0.4.1-1PBJVxB3M1LJQYlX7usHnQ
    ghc-typelits-natnormalise-0.7.3-GWgKky7sp6iDbg9EMqBW0z
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-knownnat/html/ghc-typelits-knownnat.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-knownnat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-knownnat-0.7.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-knownnat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-knownnat
version:              0.7.5
visibility:           public
id:                   ghc-typelits-knownnat-0.7.5-JnSPQzwpSIOITveutXzz68
key:                  ghc-typelits-knownnat-0.7.5-JnSPQzwpSIOITveutXzz68
license:              BSD-2-Clause
copyright:
    Copyright © 2016     , University of Twente,
    2017-2018, QBayLogic B.V.,
    2017     , Google Inc.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://clash-lang.org/
synopsis:             Derive KnownNat constraints from other KnownNat constraints
description:
    A type checker plugin for GHC that can derive \"complex\" @KnownNat@
    constraints from other simple/variable @KnownNat@ constraints. i.e. without
    this plugin, you must have both a @KnownNat n@ and a @KnownNat (n+2)@
    constraint in the type signature of the following function:

    @
    f :: forall n . (KnownNat n, KnownNat (n+2)) => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @

    Using the plugin you can omit the @KnownNat (n+2)@ constraint:

    @
    f :: forall n . KnownNat n => Proxy n -> Integer
    f _ = natVal (Proxy :: Proxy n) + natVal (Proxy :: Proxy (n+2))
    @

    The plugin can derive @KnownNat@ constraints for types consisting of:

    * Type variables, when there is a corresponding @KnownNat@ constraint

    * Type-level naturals

    * Applications of the arithmetic expression: +,-,*,^

    * Type functions, when there is either:

    1. a matching given @KnownNat@ constraint; or

    2. a corresponding @KnownNat\<N\>@ instance for the type function

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.KnownNat.Solver
    @

    Pragma to the header of your file.

category:             Type System
abi:                  3b50cfa8c3cab27ba91c4f5696154630
exposed:              True
exposed-modules:      GHC.TypeLits.KnownNat GHC.TypeLits.KnownNat.Solver
hidden-modules:       GHC.TypeLits.KnownNat.TH
import-dirs:          /usr/lib/ghc-8.10.4/site-local/ghc-typelits-knownnat-0.7.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ghc-typelits-knownnat-0.7.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/ghc-typelits-knownnat-0.7.5

hs-libraries:         HSghc-typelits-knownnat-0.7.5-JnSPQzwpSIOITveutXzz68
depends:
    base-4.14.1.0 ghc-8.10.4 ghc-prim-0.6.1
    ghc-tcplugins-extra-0.4.1-9APDS7LSv4p3uu7LEAMK38
    ghc-typelits-natnormalise-0.7.4-GW3GANRgdcWACy5yLyR92v
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-knownnat/html/ghc-typelits-knownnat.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-knownnat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
